@@ -91,6 +91,7 @@ def get_parser(args):
     parallel.add_argument('--serial', dest='parallel', action='store_false',
                           help='Run tests serially')
     parser.add_argument('--concurrency', '-c', type=int, metavar='WORKERS',
+                        default=0,
                         help='The number of workers to use when running in '
                              'parallel. By default this is the number of cpus')
     parser.add_argument('--until-failure', action='store_true',
@@ -106,6 +107,35 @@ def get_parser(args):
     return parser.parse_known_args(args)
 
 
+def _parse_testrconf():
+    # Parse the legacy .testr.conf file.
+    test_dir = None
+    top_dir = None
+    group_regex = None
+
+    with open('.testr.conf', 'r') as testr_conf_file:
+        config = six.moves.configparser.ConfigParser()
+        config.readfp(testr_conf_file)
+        test_command = config.get('DEFAULT', 'test_command')
+        group_regex = None
+        if config.has_option('DEFAULT', 'group_regex'):
+            group_regex = config.get('DEFAULT', 'group_regex')
+
+    for line in test_command.split('\n'):
+        if 'subunit.run discover' in line:
+            command_parts = line.split(' ')
+            top_dir_present = '-t' in line
+            for idx, val in enumerate(command_parts):
+                if top_dir_present:
+                    if val == '-t':
+                        top_dir = command_parts[idx + 1]
+                        test_dir = command_parts[idx + 2]
+                else:
+                    if val == 'discover':
+                        test_dir = command_parts[idx + 1]
+    return (test_dir, top_dir, group_regex)
+
+
 def call_testr(regex, subunit, pretty, list_tests, slowest, parallel, concur,
                until_failure, color, others=None, blacklist_file=None,
                whitelist_file=None, black_regex=None, load_list=None):
@@ -115,30 +145,11 @@ def call_testr(regex, subunit, pretty, list_tests, slowest, parallel, concur,
     group_regex = None
     if not os.path.isfile('.stestr.conf') and os.path.isfile('.testr.conf'):
         msg = ('No .stestr.conf file found in the CWD. Please create one to '
-               'to replace the .testr.conf. You can find a script to do this '
-               'in the stestr git repository.')
+               'replace the .testr.conf file. You can find a script to do '
+               'this in the stestr git repository.')
         warnings.warn(msg)
 
-        with open('.testr.conf', 'r') as testr_conf_file:
-            config = six.moves.configparser.ConfigParser()
-            config.readfp(testr_conf_file)
-            test_command = config.get('DEFAULT', 'test_command')
-            group_regex = None
-            if config.has_option('DEFAULT', 'group_regex'):
-                group_regex = config.get('DEFAULT', 'group_regex')
-
-        for line in test_command.split('\n'):
-            if 'subunit.run discover' in line:
-                command_parts = line.split(' ')
-                top_dir_present = '-t' in line
-                for idx, val in enumerate(command_parts):
-                    if top_dir_present:
-                        if val == '-t':
-                            top_dir = command_parts[idx + 1]
-                            test_dir = command_parts[idx + 2]
-                    else:
-                        if val == 'discover':
-                            test_dir = command_parts[idx + 2]
+        test_dir, top_dir, group_regex = _parse_testrconf()
     elif not os.path.isfile(
         '.testr.conf') and not os.path.isfile('.stestr.conf'):
         msg = ('No .stestr.conf found, please create one.')
@@ -174,7 +185,9 @@ def call_testr(regex, subunit, pretty, list_tests, slowest, parallel, concur,
 
 def call_subunit_run(test_id, pretty, subunit):
     env = copy.deepcopy(os.environ)
-    cmd_save_results = ['testr', 'load', '--subunit']
+    cmd_save_results = ['stestr', 'load', '--subunit']
+    if not os.path.isdir('.stestr'):
+        commands.init_command()
 
     if pretty:
         # Use subunit run module
@@ -222,6 +235,10 @@ def _select_and_call_runner(opts, exclude_regex, others):
 
 
 def ostestr(args):
+    msg = ('Deprecate: ostestr command is deprecated now. Use stestr '
+           'command instead. For more information: '
+           'https://docs.openstack.org/os-testr/latest/user/ostestr.html')
+    warnings.warn(msg)
     opts, others = get_parser(args)
     if opts.pretty and opts.subunit:
         msg = ('Subunit output and pretty output cannot be specified at the '
